# RentalFileCommentIn


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**comment** | **str** |  | 

## Example

```python
from core.v2.models.rental_file_comment_in import RentalFileCommentIn

# TODO update the JSON string below
json = "{}"
# create an instance of RentalFileCommentIn from a JSON string
rental_file_comment_in_instance = RentalFileCommentIn.from_json(json)
# print the JSON string representation of the object
print(RentalFileCommentIn.to_json())

# convert the object into a dict
rental_file_comment_in_dict = rental_file_comment_in_instance.to_dict()
# create an instance of RentalFileCommentIn from a dict
rental_file_comment_in_from_dict = RentalFileCommentIn.from_dict(rental_file_comment_in_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


